=======
VFormer
=======


.. image:: https://github.com/SforAiDl/vformer/actions/workflows/package-test.yml/badge.svg
        :target: https://github.com/SforAiDl/vformer/actions/workflows/package-test.yml

.. image:: https://readthedocs.org/projects/vformer/badge/?version=latest
        :target: https://vformer.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status

.. image:: https://codecov.io/gh/SforAiDl/vformer/branch/main/graph/badge.svg?token=5QKCZ67CM2
        :target: https://codecov.io/gh/SforAiDl/vformer/branch/main
        :alt: Code Coverage

.. image:: https://img.shields.io/pypi/v/vformer.svg
        :target: https://pypi.python.org/pypi/vformer


A modular PyTorch library for vision transformer models


* Free software: MIT license
* Documentation: https://vformer.readthedocs.io.
